/* empty.c
 *
 * Copyright 2018 Bruce Cowan <bruce@bcowan.me.uk>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 */

#include <glib.h>

#include "array.h"

typedef struct
{
    Array *array;
} ArrayFixture;

static void
create_array (ArrayFixture *fixture,
              gconstpointer user_data)
{
    fixture->array = array_new (NULL);
}

static void
test_length (ArrayFixture *fixture,
             gconstpointer user_data)
{
    size_t length = array_get_length (fixture->array);

    g_assert_cmpint (length, ==, 0);
}

static void
test_remove_fast (ArrayFixture *fixture,
                  gconstpointer user_data)
{
    gboolean success = array_remove_fast (fixture->array, 1);
    g_assert_false (success);
}

static void
test_remove (ArrayFixture *fixture,
             gconstpointer user_data)
{
    gboolean success = array_remove (fixture->array, 1);
    g_assert_false (success);
}

static void
test_get (ArrayFixture *fixture,
          gconstpointer user_data)
{
    const void *element = array_get (fixture->array, 1);

    g_assert_null (element);
}

static void
test_set (ArrayFixture *fixture,
          gconstpointer user_data)
{
    gboolean success = array_set (fixture->array, 1, NULL);
    g_assert_false (success);
}

static void
destroy_array (ArrayFixture *fixture,
               gconstpointer user_data)
{
    array_unref (fixture->array);
}

int
main (int    argc,
      char **argv)
{
    g_test_init (&argc, &argv, NULL);

    g_test_add ("/array/length", ArrayFixture, NULL,
                create_array, test_length, destroy_array);
    g_test_add ("/array/remove_fast", ArrayFixture, NULL,
                create_array, test_remove_fast, destroy_array);
    g_test_add ("/array/remove", ArrayFixture, NULL,
                create_array, test_remove, destroy_array);
    g_test_add ("/array/get", ArrayFixture, NULL,
                create_array, test_get, destroy_array);
    g_test_add ("/array/set", ArrayFixture, NULL,
                create_array, test_set, destroy_array);

    return g_test_run ();
}
